emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/calendar/cal-move.el,v


From: Glenn Morris
Subject: [Emacs-diffs] Changes to emacs/lisp/calendar/cal-move.el,v
Date: Thu, 26 Jun 2008 03:41:38 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Glenn Morris <gm>       08/06/26 03:41:38

Index: cal-move.el
===================================================================
RCS file: /sources/emacs/emacs/lisp/calendar/cal-move.el,v
retrieving revision 1.32
retrieving revision 1.33
diff -u -b -r1.32 -r1.33
--- cal-move.el 21 Jun 2008 19:28:42 -0000      1.32
+++ cal-move.el 26 Jun 2008 03:41:38 -0000      1.33
@@ -32,27 +32,38 @@
 ;; FIXME should calendar just require this?
 (require 'calendar)
 
+
+;; Note that this is not really the "closest" date.
+;; In most cases, it just searches forwards for the next day.
 ;;;###cal-autoload
 (defun calendar-cursor-to-nearest-date ()
   "Move the cursor to the closest date.
 The position of the cursor is unchanged if it is already on a date.
 Returns the list (month day year) giving the cursor position."
   (or (calendar-cursor-to-date)
-      (let ((column (current-column)))
-        (when (> calendar-first-date-row (count-lines (point-min) (point)))
+      (let* ((col (current-column))
+             (edges (cdr (assoc (calendar-column-to-segment)
+                                calendar-month-edges)))
+             (last (nth 2 edges))
+             (right (nth 3 edges)))
+        (when (< (count-lines (point-min) (point)) calendar-first-date-row)
           (goto-line calendar-first-date-row)
-          (move-to-column column))
-        ;; FIXME the date positions are fixed and computable,
-        ;; but searching is probably more flexible.
-        ;; Note also that this may not be the "nearest" date.
-        ;; Eg with cursor just after end of month, can skip to next month.
-        (or (looking-at "[0-9]")
+          (move-to-column col))
+        ;; The date positions are fixed and computable, but searching
+        ;; is probably more flexible.  Need to consider blank days at
+        ;; start and end of month if computing positions.
+        ;; 'date text-property is used to exclude intermonth text.
+        (unless (and (looking-at "[0-9]")
+                     (get-text-property (point) 'date))
             ;; We search forwards for a number, except close to the RH
             ;; margin of a month, where we search backwards.
+          ;; Note that the searches can go to other lines.
             (if (or (looking-at " *$")
-                    (< (calendar-column-to-month) 0))
-                (re-search-backward "[0-9]" nil t)
-              (re-search-forward "[0-9]" nil t)
+                  (and (> col last) (< col right)))
+              (while (and (re-search-backward "[0-9]" nil t)
+                          (not (get-text-property (point) 'date))))
+            (while (and (re-search-forward "[0-9]" nil t)
+                        (not (get-text-property (1- (point)) 'date))))
               (backward-char 1)))
         (calendar-cursor-to-date))))
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]